"""
Constants used throughout the dataset labeler.
"""

# CSV field order for output files
CSV_FIELDNAMES = [
    'file_name',
    'md5',
    'label',
    'file_type',
    'CPU',
    'bits',
    'endianness',
    'load_segments',
    'is_stripped',
    'has_section_name',
    'family',
    'first_seen',
    'size',
    'diec_is_packed',
    'diec_packer_info',
    'diec_packing_method'
]
